==> pf4-component-mapper-3.2.0.tgz: package/esm/time-picker/time-picker.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import FormGroup from '../form-group/form-group';
import { TextInput } from "@patternfly/react-core/dist/esm/components/TextInput/TextInput.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import PropTypes from 'prop-types';
import showError from '../show-error/show-error';

var TimePicker = function TimePicker(props) {
  var _useFieldApi = useFieldApi(props),
      label = _useFieldApi.label,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      hideLabel = _useFieldApi.hideLabel,
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      id = _useFieldApi.id,
      FormGroupProps = _useFieldApi.FormGroupProps,
      rest = _objectWithoutProperties(_useFieldApi, ["label", "isRequired", "helperText", "meta", "validateOnMount", "description", "hideLabel", "input", "isReadOnly", "isDisabled", "id", "FormGroupProps"]);

  return /*#__PURE__*/React.createElement(FormGroup, {
    label: label,
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: hideLabel,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(TextInput, _extends({}, showError(meta, validateOnMount), input, rest, {
    type: "time",
    id: id || input.name,
    isReadOnly: isReadOnly,
    isDisabled: isDisabled
  })));
};

TimePicker.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  isDisabled: PropTypes.bool,
  id: PropTypes.string,
  FormGroupProps: PropTypes.object
};
export default TimePicker;

==> pf4-component-mapper-3.4.1.tgz: package/esm/time-picker/time-picker.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import FormGroup from '../form-group/form-group';
import { TimePicker as PF4TimePicker } from "@patternfly/react-core/dist/esm/components/TimePicker/TimePicker.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import PropTypes from 'prop-types';

var TimePicker = function TimePicker(props) {
  var _useFieldApi = useFieldApi(props),
      label = _useFieldApi.label,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      hideLabel = _useFieldApi.hideLabel,
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      id = _useFieldApi.id,
      FormGroupProps = _useFieldApi.FormGroupProps,
      rest = _objectWithoutProperties(_useFieldApi, ["label", "isRequired", "helperText", "meta", "validateOnMount", "description", "hideLabel", "input", "isReadOnly", "isDisabled", "id", "FormGroupProps"]);

  return /*#__PURE__*/React.createElement(FormGroup, {
    label: label,
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: hideLabel,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(PF4TimePicker, _extends({}, input, {
    defaultTime: input.value
  }, rest, {
    id: id || input.name,
    isDisabled: isDisabled || isReadOnly
  })));
};

TimePicker.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  isDisabled: PropTypes.bool,
  id: PropTypes.string,
  FormGroupProps: PropTypes.object
};
export default TimePicker;
